@@ -6,7 +6,7 @@ package Acme::MetaSyntactic::donmartin;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.004';
+our $VERSION = '1.005';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -73,6 +73,12 @@ Vahe Sarkissian.
 
 =item *
 
+2018-10-29 - v1.005
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.052.
+
+=item *
+
 2016-03-21 - v1.004
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.049.
@@ -550,7 +556,7 @@ KIPF_KAPF_KOFF_KOFF
 KIPF_KIPF
 KISS_KISS_KISS_KISS
 KITTOONG_SHKLUNK
-KKCHK_CRACKLE_CRUNCH
+KKCHK_CRACKLE_KRUNCH
 KKCHK_FEW
 KKKKKKKKKKKK_KAKROOSH
 KKKSH_KKKSH
