@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::iata;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.004';
+our $VERSION = '1.005';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -33,6 +33,12 @@ Abigail, Philippe Bruhat (BooK)
 
 =item *
 
+2019-07-29 - v1.005
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.053.
+
+=item *
+
 2018-10-29 - v1.004
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.052.
@@ -146,7 +152,7 @@ CAJ CAK CAL CAM CAN CAO CAP CAQ CAR CAS CAT CAU CAV CAW CAX CAY CAZ CBA
 CBB CBC CBD CBE CBF CBG CBH CBI CBJ CBK CBL CBM CBN CBO CBP CBQ CBR CBS
 CBT CBU CBV CBW CBX CBY CBZ CCA CCB CCC CCD CCE CCF CCG CCH CCI CCJ CCK
 CCL CCM CCN CCO CCP CCQ CCR CCS CCT CCU CCV CCW CCX CCY CCZ CDA CDB CDC
-CDE CDF CDG CDH CDI CDJ CDK CDL CDN CDO CDP CDQ CDR CDS CDU CDV CDW CDY
+CDE CDF CDG CDH CDI CDJ CDK CDL CDN CDO CDP CDQ CDR CDS CDT CDU CDV CDW CDY
 CEA CEB CEC CED CEE CEF CEG CEH CEI CEJ CEK CEL CEM CEN CEO CEP CEQ CER
 CES CET CEU CEV CEW CEX CEY CEZ CFA CFC CFD CFE CFF CFG CFH CFI CFK CFN
 CFO CFP CFQ CFR CFS CFT CFU CFV CGA CGB CGC CGD CGE CGF CGG CGH CGI CGJ
@@ -266,7 +272,7 @@ IML IMM IMN IMO IMP IMT IMZ INA INB INC IND INE INF ING INH INI INJ INK
 INL INM INN INO INQ INR INS INT INU INV INW INX INY INZ IOA IOK IOM ION
 IOP IOR IOU IOW IPA IPC IPE IPG IPH IPI IPL IPN IPT IPU IPW IQM IQN IQQ
 IQT IRA IRB IRC IRD IRE IRG IRI IRJ IRK IRN IRO IRP IRS ISA ISB ISC ISE
-ISG ISH ISI ISJ ISK ISL ISM ISN ISO ISP ISQ ISS IST ISW ITA ITB ITE ITH
+ISG ISH ISI ISJ ISK ISL ISM ISN ISO ISP ISQ ISS IST ISU ISW ITA ITB ITE ITH
 ITI ITJ ITK ITM ITN ITO ITP ITQ ITR IUD IUE IUL IUM IUS IVA IVC IVG IVH
 IVL IVO IVR IVW IWA IWD IWH IWI IWJ IWO IWS IXA IXB IXC IXD IXE IXG IXH
 IXI IXJ IXK IXL IXM IXN IXP IXQ IXR IXS IXT IXU IXV IXW IXY IXZ IYK IZG
