@@ -2,21 +2,26 @@ package Acme::MetaSyntactic::pornstars;
 use strict;
 use Acme::MetaSyntactic::MultiList;
 our @ISA = qw( Acme::MetaSyntactic::MultiList );
-our $VERSION = '1.031';
+our $VERSION = '1.032';
 __PACKAGE__->init();
 
 our %Remote = (
-    source => {
-    },
+    source => 'https://en.wikipedia.org/wiki/List_of_pornographic_performers_by_decade',
     extract => sub {
         $_[0] =~ s/<h2>(?:<[^>]*>)?References<.*//s;    # drop everything after references
-        return
+        my @items =
             map { Acme::MetaSyntactic::RemoteList::tr_accent($_) }
             map { Acme::MetaSyntactic::RemoteList::tr_utf8_basic($_) }
             grep { ! /^List_|_Groups$/ }
             map { s/[-\s'\x{2019}]/_/g; s/[."]//g; $_ }
-            $_[0]
-            =~ m{^<li>(?:<a [^>]*>)?(.*?)(?:(?: ?[-,(<]| aka | see ).*)?</li>}mig
+	    grep $_,
+            $_[0] =~ m{^<h3><span[^>]*>((?:Fem|M)ale)</span>|^(?:<ul>)?<li>(?:<a [^>]*>)?(.*?)(?:(?: ?[-,(<]| aka | see ).*)?</li>}mig;
+        my ( $category, @list );
+        for (@items) {
+            if (/^(?:Fem|M)ale$/) { $category = lc; next; }
+            push @list, $_ if $category eq $_[1];
+        }
+	return @list;
     },
     ,
 );
@@ -45,6 +50,12 @@ L<http://en.wikipedia.org/wiki/List_of_pornographic_actresses_by_decade>
 as a source for female actresses, but no source for male performers.
 The data for the C<male> category is therefore B<obsolete>.
 
+In October 2018, that source was removed from this theme, making it static.
+
+In May 2018, the link above was redirected to
+L<https://en.wikipedia.org/wiki/List_of_pornographic_performers_by_decade>,
+which became the new source of data for both categories as of July 2019.
+
 =head1 CONTRIBUTORS
 
 On September 15, 2013, while I was digging for the responsible parties,
@@ -59,6 +70,20 @@ Sbastien Aperghis-Tramoni, Philippe Bruhat, Rafal Garcia-Suarez.
 
 =item *
 
+2019-07-29 - v1.032
+
+Updated with a new remote source for pornstars of both genders
+in Acme-MetaSyntactic-Themes version 1.053.
+
+=item *
+
+2018-10-29 - v1.031
+
+Abandonned the remote source for female pornstars, no data change,
+in Acme-MetaSyntactic-Themes version 1.052.
+
+=item *
+
 2017-11-13 - v1.031
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.051.
@@ -370,467 +395,674 @@ __DATA__
 Abella_Danger
 Adriana_Chechik
 Adrianna_Luna
+Ai_Iijima
+Aino_Kishi
+Air_Force_Amy
+Aja
 AJ_Applegate
+Akari_Asahina
+Akiho_Yoshizawa
 Alana_Evans
-Aletta_Ocean
+Aleska_Diamond
 Alexandra_Quinn
+Alexandra_Silk
+Alexis_Amore
+Alexis_Texas
 Alex_Taylor
+Alia_Janine
+Alina_Plugaru
+Alisha_Klass
 Allie_Haze
+Ally_Mac_Tyana
+Amarna_Miller
 Amber_Lynn
 Amber_Rayne
 Amy_Fisher
 Andrea_True
+Andy_San_Dimas
+Angela_White
+Angel_Dark
+Angelica_Bella
+Angelina_Armani
+Angel_Kelly
 Anikka_Albrite
+Anksa_Kara
+Annabel_Chong
 Anna_Malle
+Anna_Polina
 Annette_Haven
+Annette_Schwarz
 Annie_Sprinkle
 April_Flores
+April_O_Neil
+Aria_Giovanni
+Ariana_Jollee
 Asa_Akira
+Asami_Jo
+Asami_Sugiura
 Ashley_Blue
+Ashley_Long
+Ashlyn_Gere
+Ashlynn_Brooke
 Asia_Carrera
 Audrey_Hollander
+August_Ames
 Aurora_Snow
-Ava_Addams
+Ava_Vincent
+Baby_Pozzi
+Bambi_Woods
+Barbara_Dare
 Belladonna
 Belle_Knox
+Bibian_Norai
 BiBi_Jones
+Bionca
+Bobbi_Eden
+Bobbi_Starr
 Bodil_Joensen
 Bonnie_Rotten
 Brandi_Love
+Brandy_Aniston
 Bree_Olson
+Briana_Banks
+Bridget_Powers
 Bridgette_Kerkove
+Brigitta_Bulgari
 Brigitte_Lahaie
 Brittany_Andrews
 Brittany_O_Connell
+Britt_Morgan
 Brooklyn_Lee
+Bunko_Kanazawa
 Calli_Cox
 Candida_Royalle
+Candy_Apples
 Candy_Barr
+Candye_Kane
 Capri_Anderson
-Cara_Lott
+Caressa_Savage
+Carmen_Hart
+Carmen_Luvana
 Carol_Connors
+Carter_Cruise
 Casey_Calvert
+Cathy_Barry
+Cathy_Stewart
+Celia_Blanco
+Celine_Bara
+Chanel_Preston
 Charmane_Star
 Chasey_Lain
+Chelsea_Charms
+Chloe
 Chloe_Jones
+Christy_Canyon
+Christy_Mack
 C_J_Laing
 Clara_Morgane
+Coralie
+Courtney_Simpson
+Crave
+Crissy_Moran
+Cytherea
 Daisy_Marie
 Dana_DeArmond
 Dana_Vespoli
 Dani_Daniels
+Daniella_Rush
+Danni_Ashe
 Debi_Diamond
+Demi_Delia
+Denice_Klarskov
+Desiree_Cousteau
+Devinn_Lane
+Devon
+Dolly_Golden
+Domonique_Simone
+Draghixa
+Dyanna_Lauren
+Dylan_Ryan
+Dylan_Ryder
+Edelweiss
+Elly_Akira
+Emanuelle_Cristaldi
 Erica_Boyer
+Erica_Ellyson
+Erica_Fontes
+Erin_Brown
 Estelle_Desanges
+Eva_Angelina
+Eva_Henger
+Eve_Angel
+Felecia
+Felicia_Fox
+Felicia_Tang
+Fiona_Richmond
 Flower_Tucci
 Francesca_Le
 Gauge
 Georgina_Spelvin
+Gianna_Michaels
+Gina_Lynn
+Gina_Wild
 Ginger_Lynn
 Gloria_Leonard
-Gracie_Glam
 Heather_Hunter
+Heather_Vandeven
 Hillary_Scott
 Holly_Ryder
+Holly_Sampson
 Houston
-Ilona_Staller
+India
+Jada_Fire
+Jada_Stevens
+Jade_Laroche
+Jana_Bach
+Janine_Lindemulder
 Jasmin_St_Claire
+Jeanna_Fine
 Jeannie_Pepper
+Jelena_Jensen
 Jenna_Haze
 Jenna_Jameson
 Jenna_Presley
+Jessa_Rhodes
 Jesse_Jane
+Jessica_Drake
+Jessica_Jaymes
 Jessie_Andrews
 Jessie_Rogers
+Jewel_De_Nyle
 Jillian_Janson
+Jill_Kelly
+Jiz_Lee
 Joanna_Angel
+Jodie_Moore
+Judy_Minx
+Julia_Alexandratou
+Julia_Ann
+Julia_Channel
+Juli_Ashton
+Julie_K_Smith
+Julie_Meadows
 Juliet_Anderson
 Justine_Joli
 Kaitlyn_Ashley
-Kandi_Barbour
+Karen_Lancaume
 Karen_Summer
 Katie_Morgan
+Katja_K
 Katja_Kassin
 Katsuni
+Kayden_Kross
 Kaylani_Lei
 Kay_Parker
+Kei_Mizutani
+Kelli_McCarty
+Kelly_Madison
+Kelly_Trump
+Kendra_Jade_Rossi
 Kendra_Lust
 Kimberly_Kane
+Kim_Chambers
+Kirsten_Price
+Kitten_Natividad
 Kleio_Valentien
+Kobe_Tai
+Kristi_Myst
 Kylie_Ireland
+Lacy_Rose
+Laly
+Lara_Roxx
+Laura_Angel
+Lauren_Brice
+Lauren_Phoenix
+Laure_Sainclair
+Lea_De_Mae
+Leena
+Leonie
+Letha_Weapons
+Lexi_Belle
+Lezley_Zen
+Lilli_Carati
+Lily_Carter
+Lily_LaBeau
 Linda_Lovelace
 Linda_Wong
+Linsey_Dawn_McKenzie
 Lisa_Ann
+Lisa_De_Leeuw
+Liza_del_Sierra
 Lizz_Tayler
+Lizzy_Borden
+Lollipop
 Lolo_Ferrari
+Lorelei_Lee
+Lucia_Lapiedra
+Lulu_Devine
 Lupe_Fuentes
 Maddy_O_Reilly
+Madison
+Madison_Young
+Mandy_Bright
+Maria_Ozawa
+Marica_Hase
 Marilyn_Chambers
+Mari_Possa
 Marlene_Willoughby
 Mary_Carey
 Marylin_Star
 Mary_Millington
+Maxi_Mounds
 May_Ling_Su
+Megan_Leigh
 Melissa_Hill
+Melissa_Midwest
+Melissa_Monet
 Mia_Khalifa
 Mia_Malkova
+Mia_Rose
+Michelle_Maylene
+Michelle_Thorne
+Michelle_Wild
+Micky_Lynn
 Midori
 Mika_Tan
+Milly_D_Abbraccio
 Mimi_Miyagi
 Missy
+Misti_Dawn
+Misty_Rain
+Misty_Stone
 Moana_Pozzi
+Monica_Mattos
+Monica_Mayhem
 Monique_Alexander
-Nikita_Denise
+Mya_Diamond
+Nana_Natsume
+Nao_Oikawa
+Nao_Saejima
+Nica_Noelle
+Nici_Sterling
+Nicki_Hunter
+Niki_Belucci
+Nikita_Gross
 Nikki_Benz
 Nikki_Charm
+Nikki_Delano
 Nikki_Dial
+Nikki_Tyler
 Nina_Hartley
+Nina_Mercedez
 Nina_Roberts
+Nozomi_Momoi
+Nyomi_Banxxx
+Olivia_Del_Rio
+Ovidie
+Patricia_Kimberly
+Patricia_Rhomberg
+Pauline_Chan
+Penny_Flame
+Penny_Pax
+P_J_Sparxx
+Poppy_Morgan
 Porsche_Lynn
+Princess_Donna
 Prinzzess
 Priya_Rai
+Puma_Swede
+Raffaela_Anderson
+Raven_Alexis
+Raven_Riley
 Raylene
+RayVeness
+Rebeca_Linares
+Rebecca_Bardoux
 Rebecca_Brooke
 Rebecca_Lord
+Rebecca_More
 Remy_LaCroix
 Rene_Bond
+Rhonda_Jo_Petty
 Riley_Reid
 Riley_Steele
+Rin_Aoki
+Roberta_Gemma
 Robin_Byrd
-Rosa_Caracciolo
+Roxy
+Salma_de_Nora
+Samantha_Bentley
+Samantha_Saint
+Sandy_Dempsey
+Saori_Hara
 Sasha_Grey
+Satine_Phoenix
 Savannah
+Savanna_Samson
+Scarlet_Young
 Seka
+Selen
+Selena_Steele
 Serena
 Serenity
+Sexy_Cora
+Shakeela
 Shane
 Sharon_Mitchell
 Shauna_Grant
-Shyla_Jennings
+Shawna_Lenee
+Shayla_LaVeaux
 Shyla_Stylez
+Shy_Love
+Silvia_Saint
+Sinnamon_Love
 Sinn_Sage
+Skin_Diamond
+Sola_Aoi
+Sonia_Baby
+Sophie_Anderson
+Sophie_Evans
 Stacey_Donovan
+Stacy_Valentine
+Stephanie_Swift
 Stormy_Daniels
+Stoya
+Sunny_Lane
 Sunny_Leone
+Sunrise_Adams
+Sunset_Thomas
+Sydnee_Steele
 Tabatha_Cash
+Tabitha_Stevens
+Tamaki_Katori
+Tania_Russof
+Tanya_Hansen
+Tanya_Tate
+Tarra_White
+Taryn_Thomas
+Tasha_Reign
+Tatum_Reed
+Tawny_Roberts
+Taylor_Hayes
 Taylor_St_Claire
 Taylor_Wane
 Teagan_Presley
 Tera_Patrick
+Tera_Wray
 Tericka_Dye
-Tiffany_Hopkins
+Teri_Weigel
+Tianna
+Tiffany_Million
+Tiffany_Mynx
+Tina_Cheri
+Tina_Yuzuki
+Toppsy_Curvey
+Tori_Black
+Tory_Lane
 Traci_Lords
+Tricia_Devereaux
+Tristan_Taormino
+Tylene_Buck
+Tyra_Misoux
 Valentina_Nappi
 Vanessa_Blue
 Vanessa_del_Rio
+Venere_Bianca
+Veronica_Avluv
+Veronica_Hart
 Vicky_Vette
+Victoria_Paris
+Victoria_Zdrok
+Violet_Blue
+Viper
+Vittoria_Risi
+Vivian_Schmitt
+Wiska
+Yasmine_Lafitte
+Yua_Aida
+Yuma_Asami
+Yuri_Komuro
+Zara_Whites
 # names male
-Adam_Wilde
-Al_Borda
-Alain_Deloin
-Alberto_Rey
-Alec_Metro
-Ales_Hanak
-Alex_Rox
-Alex_Sanders
-Alexander_Devoe
+Aaron_Lawrence
+Aiden_Shaw
+Alban_Ceray
 Alexandre_Frota
-Andre_Chazel
-Andrea_Nobili
+Alex_Sanders
+Anthony_Crane
+Anthony_Rosano
+Arpad_Miklos
 Barrett_Blade
-Barry_Wood
 Ben_Dover
-Ben_English
-Ben_Hardy
-Benjamin_Brat
-Big_Herc
-Biggz
-Biff_Malibu
-Billy_Banks
+Billy_Brandt
 Billy_Dee
 Billy_Glide
-Bobby_Blake
+Billy_Herrington
+Blake_Harper
+Blake_Palmer
+Bobby_Astyr
+Bobby_Hollander
 Bobby_Vitale
-Boz
 Brad_Armstrong
-Brandon_Iron
-Brett_McCoy
-Brett_Rockman
+Bradford_Thomas_Wagner
+Brad_Patton
+Brandon_Lee
+Brendon_Miller
+Bret_Wolfe
 Brian_Pumper
-Brian_Surewood
-Brick_Majors
-Brock
-Bruno_Sx
-Brutus_Black
 Buck_Adams
-Byron_Long
-Cal_Jammer
-Captain_Bob
-Carlos_Krystal
-Carmelo_Petix
-Chance_Ryder
-Cheyne_Collins
-Chris_Cannon
-Chris_Charming
-Chris_Evans
-Chris_small_package_Marshman
+Cameron_Jackson
+Carter_Stevens
+Casey_Donovan
+Chad_Knight
+Charles_Dera
+Chocoball_Mukai
+Choky_Ice
+Chris_Steele
+Christian_XXX
 Christoph_Clark
-Claudio_Meloni
-Colt_Steele
+Cole_Taylor
+Cole_Tucker
+Cole_Youngblood
+Colton_Ford
 Dale_DaBone
-Daniel_Espinoza
-Daniel_Kane
-Daniel_Thuerrigl
+Danny_Mountain
+Danny_Wylde
 Darren_James
 Dave_Cummings
-Dave_Hardman
-David_Christopher
-David_Cahse
-David_Perry
-David_Ruby
-Deep_Threat
-Devlin_Weed
-Dez
-Dick_Dashton
-Dick_Delaware
-Dick_Nasty
-Dick_Rambone
-Dillion_Day
-Dino_Bravo
-Dino_Toscani
+David_Aaron_Clark
+Dawson
+Derek_Hay
+Derrick_Pierce
+Dick_Smothers_Jr
+Diesel_Washington
+Dillon_Day
 Don_Fernando
-Don_Hollywood
-Donny_Long
+Dylan_Vox
+Eddie_Stone
 Ed_Powers
-Ed_Luistro
-Eduardo_Yanez
-Elone_Disere
-Eric_Manchester
-Eric_Masterson
-Eric_Price
+Eric_Edwards
+Eric_Stryker
 Erik_Everhard
-Etienne_Jaumillot
+Erik_Rhodes
+Evan_Seinfeld
 Evan_Stone
-Frankie_Jay
-Falcon_X
-Ficky_Martin
-FM_Bradley
-Francesco_Malcom
-Franco_Roccaforte
-Franco_Trentalance
-Francois_Papillon
-Frank_Gun
-Frank_Major
-Frank_Shaft
-Frank_Towers
-Frankie_Versace
-Gene_Ross
+Flash_Brown
+Flex
+Francois_Sagat
+Fred_Halsted
+Fred_J_Lincoln
+Fredrik_Eklund
 George_Payne
 George_Uhl
-Gerard_Luig
-Gigantua
-Gilbert_Servien
-Gino_Greco
-Greg_Rome
-Greg_Centauro
-Guy_Bonnafoux
-Guy_DaSilva
-Guy_Masse
-Hank_Rose
+Gunner_de_Medici
 Harry_Reems
-Henry_Pachard
+Harry_S_Morgan
+Henry_Saari
 Herschel_Savage
-HPG
-Ian_Daniels
+Holly_One
 Ian_Scott
-Iron_Lee
-Jack_Baker
-Jack_Bravo
-Jack_Hammer
 Jack_Napier
-Jack_Surf
-Jack_Wrangler
-Jacques_Insermini
-Jake_Ryan
-Jake_Steed
-James_Bonn
-James_Brossman
+Jack_Radcliffe
+James_Deen
 Jamie_Gillis
-Jan_Olav_Norberg
-Jason_Zupalo
-Jasper_Wade
-Jay_Ashley
-Jay_Crew
-Jean
-Jean_Pierre_Armand
-Jean_Louis
-Jean_Roche
-Jean_Yves_LeCastel
+Jan_Fischer
+Jan_Novak
+Jason_Hawke
+Jay_Grdina
+Jean_Val_Jean
+Jeff_Palmer
 Jeff_Stryker
 Jeremy_Tucker
 Jerry_Butler
-J_J_Michaels
-Joachim_Kessef
-Joel_Lawrence
-Joey_Ray
-Joey_Hafley
+Jesse_Santana
 Joey_Silvera
-John_Dough
+Johan_Paulik
+John_Bailey
+John_B_Root
 John_Holmes
 John_Leslie
-Johnny_Nineteen
-John_Slovak
+Johnnie_Keyes
+Johnny_Hazzard
+Johnny_Rahm
+Johnny_Sins
 John_Stagliano
 John_Strong
-John_West
+Jonathan_De_Falco
 Jonathan_Morgan
-Jonathan_Stern
 Jon_Dough
-Johnny_Depth
-Jolth_Walton
+Jon_Vincent
+Jordi_El_Nino_Polla
+Josh_Weston
 Jules_Jordan
-Julian
-Juliano_Ferraz
-Julian_St_Jox
-Justin_Berry
 Justin_Slayer
-Kato_Kalin
+Keiran_Lee
+Keni_Styles
 Ken_Ryker
-Kid_Jamaica
+Ken_Shimizu
+Kent_North
+Kevin_James
+Kostas_Gousgounis
+Kristen_Bjorn
 Kurt_Lockwood
-Kyle_Stone
-Lee_Stone
-Leslie_Taylor
-Lex_Baldwin
+Leo_Ford
 Lexington_Steele
+Logan_McCree
+Long_Dong_Silver
 Luc_Wylder
-Mr_18_inch
+Luka_Magnotta
+Lukas_Ridgeston
 Mandingo
 Manuel_Ferrara
-Marc_Cummings
+Manu_Pluton
+Marco_Banderas
 Marc_Stevens
 Marc_Wallice
-Marco_Duato
-Mario_Rossi
-Mark_Anthony
-Mark_Ashley
+Mark_Dalton
 Mark_Davis
-Mark_Sloan
 Mark_Wood
-Marty_Romano
-Matt_Drake
+Matthew_Rush
+Matt_Sanchez
 Max_Hardcore
+Michael_Brandon
+Michael_Gaunt
 Michael_J_Cox
+Michael_Lucas
+Michael_Morrison
 Michael_Stefano
-Mike_Feline
-Mike_Foster
+Mick_Blue
+Micky_Yanai
+Mike_Adriano
+Mike_Dreyden
 Mike_Horner
-Mike_Ranger
+Mike_John
 Mike_South
-Mickey_G
-Miles_Malone
-Mr_Lothar
+Miles_Long
 Mr_Marcus
 Mr_Pete
 Nacho_Vidal
-Nat_Turnher
-Nick_East
-Nick_Lang
 Nick_Manning
-Nikko_Knight
-Matt_Bixel
-Neeo
-Pascal_Saint
+Omar_Galanti
 Pat_Myne
-Paul_Barresi
-Paul_Cox
+Patrick_Collins
+Paul_Baxendale
 Paul_Thomas
-Peter_Foster
-Peter_Ho
+Peter_Berlin
 Peter_North
-Peter_Shaft
 Philippe_Dean
-Philippe_Soine
-Pier_Evergreen
 Pierre_Woodman
-Preston_Parker
+Prince_Yahshua
+Ramon_Nomar
+Randy_Cochran
 Randy_Spears
 Randy_West
-Ray_Victory
-Remigio_Zampa
-Ricardo_Bell
-Richard_Langin
-Rich_Handsome
-Rick_Masters
-Rick_Lee
-Rob_Rotten
-Robbie_James
-Robert_Darcy
-Robert_Rosenberg
-Roberto_Malone
-Rod_Danger
-Rodney_Moore
-Ronnie_Coxx
-Rocco_Rizzoli
-Rocco_Siffredi
-Rod_Fontana
-Ron_Jeremy
-Ryan_Idol
+Raul_Cristian
+Ray_Dragon
+R_C_Horsch
+Rex_Chandler
+Richard_Holt_Locke
 Richard_Pacheco
-Samson_Biceps
-Sam_Strong
-Sascha
-Scott_Lyons
-Scott_Styles
+Rick_Cassidy
+Ricky_Martinez
+Ricky_Sinz
+R_J_Danvers
+Robert_Bullock
+Robert_Kerman
+Roberto_Malone
+Rob_Rotten
+Rocco_Reed
+Rocco_Siffredi
+Rod_Barry
+Rod_Fontana
+Rodney_Moore
+Ron_Hightower
+Ron_Jeremy
+Ryan_Driller
+Ryan_Idol
+Sasha_Gabor
+Scott_O_Hara
+Scott_Schwartz
 Sean_Michaels
-Sebastian_Barrio
-Sergio_Suarez
-Shane_Diesel
-Slim_Dawg
-Silvio_Evangelista
-Simon_Rex
-Skunk_Riley
-Sledge_Hammer
-Spyder_Jonez
-Stephen_Wolfe
+Sean_Paul_Lockhart
+Seth_Gamble
+Seymore_Butts
+Shigeo_Tokuda
+Sonny_Landham
+Stephen_Clancy_Hill
+Stephen_Geoffreys
+Steve_Drake
 Steve_Holmes
-Steve_Hooper
-Steve_York
-Steve_Powers
+Steven_Daigle
 Steven_St_Croix
-T_J_Cummings
-TT_Boy
+Stoney_Curtis
+Taka_Kato
+Thierry_Schaffauser
+Thom_Barron
+Tiger_Tyson
+Till_Kraemer
+Tim_Kramer
+Tim_Lake
+Tim_Von_Swine
+Titof
 Tom_Byron
-Tom_Cruiso
-Tony_DeSergio
-Tony_Everready
-Tony_Martino
-Tony_Michaels
-Toni_Ribas
+Tom_Judson
+Tommy_Gunn
+Tommy_Hansen
+Tommy_Pistol
+Tony_Ooki
 Tony_Tedeschi
-Tony_Sexton
-Trent_Tesoro
-Trevor_Zen
-Tyce_Bune
-Tyler_Knight
-Ty_Lattimore
-Tom_Shepard
-Valentino_Rey
-Van_Damage
-Van_Darkholme
+Torbe
+T_T_Boy
+Tyson_Cane
+Vidkid_Timo
+Vince_Rockland
 Vince_Vouyer
-Voodoo
-Walter_Midolo
-Wes_Bauer
+Wade_Nichols
+War_Machine
 Wesley_Pipes
-Will_Ravage
-Willi_Montana
-Willy_Braque
 Wilde_Oscar
-Woody_Long
-Yoshiya_Minami
-Yves_Baillat
-Yves_Callas
-Zake_Thomas
-Zensa_Raggi
-Zare_Prejaki
+Will_Clark
+William_Margold
+Xander_Corvus
+Zak_Smith
+Zeb_Atlas
